import "../styles/App.scss"
import "../styles/globals.scss"
import "../styles/grid2.scss"
import "../styles/grid.scss"
import { SessionProvider } from "next-auth/react"
import type { AppProps } from "next/app"
import { Dispatch, SetStateAction, createContext, useState } from "react"
import { ToastContainer } from "react-toastify"
import "react-toastify/dist/ReactToastify.css"

interface gameContext {
  pin?: string
  game?: {
    id: string
  }
  player?: {
    id: string
    name?: string
    isOwner?: boolean
  }
  enemy?: {
    id: string
    name?: string
  }
}

export const gameContext = createContext<
  [gameContext, Dispatch<SetStateAction<gameContext>>]
>([{}, () => {}])

export default function App({
  Component,
  pageProps: { session, ...pageProps },
}: AppProps) {
  const gameProps = useState<gameContext>({})
  return (
    <SessionProvider session={session}>
      <gameContext.Provider value={gameProps}>
        <Component {...pageProps} />
        <ToastContainer />
      </gameContext.Provider>
    </SessionProvider>
  )
}
