import prisma from "@lib/prisma"
import { PrismaAdapter } from "@next-auth/prisma-adapter"
import { NextApiHandler } from "next"
import NextAuth, { NextAuthOptions } from "next-auth"
import AzureADProvider from "next-auth/providers/azure-ad"
import EmailProvider from "next-auth/providers/email"
import {
  uniqueNamesGenerator,
  Config,
  adjectives,
  animals,
  NumberDictionary,
} from "unique-names-generator"

const numberDictionary = NumberDictionary.generate({ min: 0, max: 999 })
const customConfig: Config = {
  dictionaries: [adjectives, animals, numberDictionary],
  separator: " ",
  style: "capital",
  length: 3,
}

const options: NextAuthOptions = {
  providers: [
    EmailProvider({
      server: process.env.EMAIL_SERVER,
      from: process.env.EMAIL_FROM,
    }),
    AzureADProvider({
      clientId: process.env.AZURE_AD_CLIENT_ID ?? "",
      clientSecret: process.env.AZURE_AD_CLIENT_SECRET ?? "",
      tenantId: process.env.AZURE_AD_TENANT_ID,
    }),
  ],
  adapter: PrismaAdapter(prisma),
  secret: process.env.SECRET,
  callbacks: {
    signIn: ({ user, account }) => {
      // Custom signIn callback to add username to email provider
      if (account && account.provider === "email") {
        user.name = uniqueNamesGenerator(customConfig) // Replace with your desired username
      }
      return true
    },
    session: ({ session, user }) => {
      if (session?.user) {
        session.user.id = user.id
      }
      return session
    },
  },
}

export { options as authOptions }

const authHandler: NextApiHandler = (req, res) => NextAuth(req, res, options)
export default authHandler
