import { authOptions } from "../auth/[...nextauth]"
import { rejectionErrors } from "@lib/backend/errors"
import sendResponse from "@lib/backend/sendResponse"
import prisma from "@lib/prisma"
import { Game } from "@prisma/client"
import type { NextApiRequest, NextApiResponse } from "next"
import { getServerSession } from "next-auth"

interface Data {
  game: Game
}

export default async function id(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const gameId = req.query.id
  const session = await getServerSession(req, res, authOptions)

  if (!session?.user || typeof gameId !== "string") {
    return sendResponse(req, res, rejectionErrors.unauthorized)
  }

  let game: Game | null
  switch (req.method) {
    case "DELETE":
      game = await prisma.game.delete({
        where: { id: gameId },
      })
      break

    default:
      game = await prisma.game.findFirst({
        where: { id: gameId },
      })
  }

  if (!game) {
    return sendResponse(req, res, rejectionErrors.gameNotFound)
  }

  sendResponse(req, res, {
    message: "Here is the game.",
    body: { game },
  })
}
