import { authOptions } from "../auth/[...nextauth]"
import { getAnyRunningGame } from "./running"
import sendResponse from "@backend/sendResponse"
import { rejectionErrors } from "@lib/backend/errors"
import prisma from "@lib/prisma"
import { CreateSchema } from "@lib/zodSchemas"
import type { NextApiRequest, NextApiResponse } from "next"
import { getServerSession } from "next-auth"
import { z } from "zod"

type Data = z.infer<typeof CreateSchema>

export default async function create(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const session = await getServerSession(req, res, authOptions)

  if (!session?.user) {
    return sendResponse(req, res, rejectionErrors.unauthorized)
  }
  const { email, id, name } = session.user

  // Generate a random 4-digit code
  const pin = Math.floor(Math.random() * 10000)
    .toString()
    .padStart(4, "0")

  let created = false

  let gameDB = await getAnyRunningGame(id)
  if (!gameDB) {
    created = true
    gameDB = await prisma.game.create({
      data: {
        gamePin: {
          create: {
            pin,
          },
        },
        users: {
          create: {
            isOwner: true,
            userId: id,
          },
        },
      },
      include: {
        gamePin: true,
        users: true,
      },
    })
  }

  const { users, gamePin, ...game } = gameDB

  return sendResponse(req, res, {
    message: `User <${email}> created game: ${game.id}`,
    statusCode: created ? 201 : 200,
    body: {
      game,
      pin: gamePin?.pin,
      player: {
        id,
        name: name ?? undefined,
        isOwner: true,
      },
    },
    type: ["debug", "infoCyan"],
  })
}
