import { authOptions } from "../auth/[...nextauth]"
import sendError from "@backend/sendError"
import sendResponse from "@backend/sendResponse"
import { rejectionErrors } from "@lib/backend/errors"
import getPinFromBody from "@lib/backend/getPinFromBody"
import prisma from "@lib/prisma"
import type { Game } from "@prisma/client"
import type { NextApiRequest, NextApiResponse } from "next"
import { getServerSession } from "next-auth"

interface Data {
  game: Game
}

export default async function join(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const session = await getServerSession(req, res, authOptions)
  const pin = await getPinFromBody(req, res)

  if (!session?.user) {
    return sendResponse(req, res, rejectionErrors.unauthorized)
  }

  const { name, email, id } = session.user

  try {
    const game = await prisma.game.findFirst({
      where: {
        gamePin: {
          pin,
        },
      },
      include: {
        users: {
          include: {
            user: true,
          },
        },
      },
    })
    if (!game) {
      return sendResponse(req, res, {
        message: "Spiel existiert nicht",
        statusCode: 404,
        type: ["infoCyan"],
      })
    }

    const player = game.users.find(({ user }) => user.id === id)?.user
    const enemy = game.users.find(({ user }) => user.id !== id)?.user

    if (!player) {
      await prisma.user_Game.create({
        data: {
          isOwner: false,
          gameId: game.id,
          userId: id,
        },
      })
    }

    return sendResponse(req, res, {
      message: `User <${email}> joined game: ${game.id}`,
      body: {
        game,
        pin,
        player: {
          id,
          name,
          isOwner: true,
        },
        enemy: {
          id: enemy?.id,
          name: enemy?.name,
          isOwner: false,
        },
      },
      type: ["debug", "infoCyan"],
    })
  } catch (err: any) {
    console.log("HERE".red, err.code, err.meta, err.message)
    throw sendError(req, res, rejectionErrors.gameNotFound)
  }
}
